/*
 * Disclaimer:
 *   This was not compiled but extracted from documentation and some code.
 */

// mylibrary.h
// In library, we skip the symbol exporting part
#ifndef SPDLOG_HELPER_H
#define SPDLOG_HELPER_H

#define SPDLOG_ACTIVE_LEVEL SPDLOG_LEVEL_TRACE//必须定义这个宏,才能输出文件名和行号
#include <memory>
#include <vector>
#include <spdlog/logger.h>
#include "spdlog/spdlog.h"
#include "spdlog/cfg/env.h"  // support for loading levels from the environment variable
#include "spdlog/fmt/ostr.h" // support for user defined types
#include "spdlog/sinks/rotating_file_sink.h"
#include <spdlog/sinks/daily_file_sink.h>
#include <spdlog/sinks/stdout_color_sinks.h>

namespace LOG
{
typedef enum {
    DEBUG=0,
    INFO,
    WARRING,
    ERROR,
}LogType;
//static const std::string logger_name = "example";
static  std::shared_ptr<spdlog::logger> setup_logger(std::string &logger_name, std::vector<spdlog::sink_ptr> sinks, LogType log_level);

static  std::shared_ptr<spdlog::logger> init_daily_log(std::string file_name, std::string model_name, bool is_stdout= true, LogType log_level=INFO)
{
  std::vector<spdlog::sink_ptr> sinks;
  auto max_size = 1048576 * 20;
  auto max_files = 5;
  if(is_stdout){
      sinks.push_back(std::make_shared<spdlog::sinks::stdout_color_sink_mt>());
  }
  sinks.push_back(std::make_shared<spdlog::sinks::rotating_file_sink_mt>(file_name, max_size, max_files));

  auto logger = setup_logger(model_name, sinks, log_level);
  return logger;
}

static  std::shared_ptr<spdlog::logger> setup_logger(std::string &logger_name, std::vector<spdlog::sink_ptr> sinks, LogType log_level)
{
  auto logger = spdlog::get(logger_name);
  spdlog::set_pattern("[%Y-%m-%d %H:%M:%S.%e][%!:%#][%l] : %v");
  if(not logger)
  {
    if(sinks.size() > 0)
    {
      logger = std::make_shared<spdlog::logger>(logger_name, std::begin(sinks), std::end(sinks));
      if(log_level == DEBUG)
        logger->set_level(spdlog::level::debug);
      else if(log_level == INFO)
        logger->set_level(spdlog::level::info);
      else if(log_level == WARRING)
        logger->set_level(spdlog::level::warn);
      else if(log_level == ERROR)
        logger->set_level(spdlog::level::err);
      logger->flush_on(spdlog::level::info);
      spdlog::register_logger(logger);
    }
    else
    {
      logger = spdlog::stdout_color_mt(logger_name);
    }

  }

  return logger;
}

//void test(std::string message)
//{
//
//  auto logger = spdlog::get(logger_name);
//  printf("??? %p\n", logger);
//  if(logger)
//  {
//    printf("222222222222222222222\n");
//    SPDLOG_LOGGER_INFO(logger, "{}::{}", __FUNCTION__, message);
//  }
//  else{
//    printf("kong\n");
//  }
//}

}
#endif